@@ -11,18 +11,12 @@ from datetime import datetime, timedelta
 from enum import Enum
 from logging import NullHandler
 from types import TracebackType
-from typing import cast, List, Optional, Tuple, Type, Union
+from typing import cast, List, Literal, Optional, Tuple, Type, Union
 
 from psutil import pid_exists
 from public import public
 
 
-try:
-    from typing import Literal
-except ImportError:                                 # pragma: nocover
-    from typing_extensions import Literal  # type: ignore
-
-
 Interval = Union[timedelta, int]
 
 # 2020-06-26(bwarsaw): Once Python 3.8 is the minimum, we could annotatey some
@@ -200,7 +194,7 @@ class Lock:
         self._retry_errnos: List[int] = []
 
     def __repr__(self) -> str:
-        return '<%s %s [%s: %s] pid=%s at %#xx>' % (
+        return '<{} {} [{}: {}] pid={} at {:#x}>'.format(
             self.__class__.__name__,
             self._lockfile,
             ('locked' if self._is_locked_no_refresh() else 'unlocked'),
@@ -284,9 +278,9 @@ class Lock:
         self,
         lifetime: Optional[Interval] = None,
         *,
-        unconditionally: bool = False
+        unconditionally: bool = False,
     ) -> None:
-        """Refreshes the lifetime of a locked file.
+        """Refresh the lifetime of a locked file.
 
         Use this if you realize that you need to keep a resource locked longer
         than you thought.
@@ -306,7 +300,7 @@ class Lock:
             self.lifetime = lifetime                # type: ignore
         # Do we have the lock?  As a side effect, this refreshes the lock!
         if not self.is_locked and not unconditionally:
-            raise NotLockedError('{}: {}'.format(repr(self), self._read()))
+            raise NotLockedError(f'{self!r}: {self._read()}')
 
     def lock(self, timeout: Optional[Interval] = None) -> None:
         """Acquire the lock.
@@ -331,7 +325,7 @@ class Lock:
         # occurrence, only happens from cron, and has only(?) been observed on
         # Solaris 2.6.
         self._touch()
-        log.debug('laying claim: {}'.format(self._lockfile))
+        log.debug(f'laying claim: {self._lockfile}')
         # For quieting the logging output.
         loopcount = -1
         while True:
@@ -343,7 +337,7 @@ class Lock:
                 # If we got here, we know we got the lock, and never
                 # had it before, so we're done.  Just touch it again for the
                 # fun of it.
-                log.debug('got the lock: {}'.format(self._lockfile))
+                log.debug(f'got the lock: {self._lockfile}')
                 self._touch()
                 break
             except OSError as error:
@@ -369,13 +363,13 @@ class Lock:
                 elif self._linkcount != 2:
                     # Somebody's messin' with us!  Log this, and try again
                     # later.  XXX should we raise an exception?
-                    log.error(
-                        'unexpected linkcount: {0:d}'.format(self._linkcount)
-                    )
+                    log.error(f'unexpected linkcount: {self._linkcount:d}')
                 elif self._read() == self._claimfile:
                     # It was us that already had the link.
-                    log.debug('already locked: {}'.format(self._lockfile))
-                    raise AlreadyLockedError('We already had the lock')
+                    log.debug(f'already locked: {self._lockfile}')
+                    raise AlreadyLockedError(
+                        'We already had the lock'
+                    ) from None
                 # Otherwise, someone else has the lock
                 pass
             # We did not acquire the lock, because someone else already has
@@ -399,7 +393,7 @@ class Lock:
             # and the expected lock lifetime hasn't expired yet either.  So
             # let's wait a while for the owner of the lock to give it up.
             elif not loopcount % 100:
-                log.debug('waiting for claim: {}'.format(self._lockfile))
+                log.debug(f'waiting for claim: {self._lockfile}')
             self._sleep()
 
     # 2020-06-27(bwarsaw): `unconditionally` should really be a keyword-only
@@ -414,6 +408,9 @@ class Lock:
         :raises NotLockedError: if we don't own the lock, either because of
             unbalanced unlock calls, or because the lock was stolen out from
             under us, unless optional ``unconditionally`` is True.
+
+        Note that successfully unlocking the lock also unlinks the claim file,
+        even if it is already unlocked and ``unconditionally`` is True.
         """
         is_locked = self.is_locked
         if not is_locked and not unconditionally:
@@ -431,7 +428,7 @@ class Lock:
         except OSError as error:
             if error.errno not in ERRORS:
                 raise
-        log.debug('unlocked: {}'.format(self._lockfile))
+        log.debug(f'unlocked: {self._lockfile}')
 
     def _is_locked_no_refresh(self) -> bool:
         """Don't refresh the lock, just return the status."""
@@ -516,6 +513,11 @@ class Lock:
         """Return the lock file name."""
         return self._lockfile
 
+    @property
+    def claimfile(self) -> str:
+        """Return the claim file name."""
+        return self._claimfile
+
     def _read(self) -> Optional[str]:
         """Read the contents of our lock file.
 
@@ -526,7 +528,7 @@ class Lock:
             try:
                 with open(self._lockfile) as fp:
                     return fp.read()
-            except EnvironmentError as error:
+            except OSError as error:
                 if error.errno in self._retry_errnos:
                     self._sleep()
                 elif error.errno not in ERRORS:
@@ -587,7 +589,7 @@ class Lock:
         # timeout was given, eventually the .lock() call will timeout.
         # However if no timeout was given, the .lock() will block forever.
         try:
-            self.details
+            self.details                            # noqa: B018
         except NotLockedError:
             log.error(
                 "lockfile exists but isn't safe to break: {}".format(
@@ -606,7 +608,7 @@ class Lock:
         # the process that claimed the lock have different owners.  Don't do
         # that.
         with suppress(PermissionError):
-            self._touch(self._lockfile)
+            self._touch(self._lockfile)             # pragma: nocover
         # Get the name of the old winner's claim file.
         winner = self._read()
         # Remove the global lockfile, which actually breaks the lock.
